@@ -29,14 +29,7 @@
 static gchar *
 gcab_test_get_filename (const gchar *filename)
 {
-    gchar *tmp;
-    char full_tmp[PATH_MAX];
-    g_autofree gchar *path = NULL;
-    path = g_build_filename (TESTDATADIR, filename, NULL);
-    tmp = realpath (path, full_tmp);
-    if (tmp != NULL)
-        return g_strdup (full_tmp);
-    return NULL;
+    return g_test_build_filename (G_TEST_DIST, filename, NULL);
 }
 
 static void
@@ -365,7 +358,7 @@ gcab_test_cabinet_load_func (void)
         };
 
         /* read file */
-        g_print ("%s... ", tests[i].fn);
+        g_test_message ("%s... ", tests[i].fn);
         fn = gcab_test_get_filename (tests[i].fn);
         g_assert (fn != NULL);
         file = g_file_new_for_path (fn);
@@ -446,7 +439,7 @@ gcab_test_cabinet_error_cves_func (void)
         g_autoptr(GInputStream) in = NULL;
 
         /* read file */
-        g_print ("%s... ", tests[i]);
+        g_test_message ("%s... ", tests[i]);
         fn = gcab_test_get_filename (tests[i]);
         g_assert (fn != NULL);
         file = g_file_new_for_path (fn);
@@ -557,7 +550,7 @@ gcab_test_cabinet_write_func (void)
         }
 
         /* write the file */
-        g_print ("%s... ", tests[i].fn);
+        g_test_message ("%s... ", tests[i].fn);
         fn_out = g_build_filename ("/tmp", tests[i].fn, NULL);
         file_out = g_file_new_for_path (fn_out);
         op = G_OUTPUT_STREAM (g_file_replace (file_out, NULL, FALSE, 0, NULL, &error));
